@@ -27,7 +27,6 @@
 #include <gtk/gtk.h>
 #include <libupower-glib/upower.h>
 
-#include "egg-debug.h"
 #include "egg-console-kit.h"
 
 #include "gpm-common.h"
@@ -65,17 +64,6 @@ cc_power_panel_help_cb (GtkWidget *widget, CcPowerPanel *panel)
 	gpm_help_display ("preferences");
 }
 
-/**
- * cc_power_panel_icon_radio_cb:
- **/
-static void
-cc_power_panel_icon_radio_cb (GtkWidget *widget, CcPowerPanel *panel)
-{
-	gint policy;
-	policy = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget), "policy"));
-	g_settings_set_enum (panel->priv->settings, GPM_SETTINGS_ICON_POLICY, policy);
-}
-
 /**
  * cc_power_panel_format_percentage_cb:
  **/
@@ -111,40 +99,20 @@ static void
 cc_power_panel_action_time_changed_cb (GtkWidget *widget, CcPowerPanel *panel)
 {
 	guint value;
-	const gint *values;
+	const GArray *values;
 	const gchar *gpm_pref_key;
 	guint active;
 
-	values = (const gint *) g_object_get_data (G_OBJECT (widget), "values");
+	values = (const GArray *) g_object_get_data (G_OBJECT (widget), "values");
 	gpm_pref_key = (const gchar *) g_object_get_data (G_OBJECT (widget), "settings_key");
 
 	active = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
-	value = values[active];
+	value = g_array_index (values, gint, active);
 
 	g_debug ("Changing %s to %i", gpm_pref_key, value);
 	g_settings_set_int (panel->priv->settings, gpm_pref_key, value);
 }
 
-/**
- * cc_power_panel_set_combo_simple_text:
- **/
-static void
-cc_power_panel_set_combo_simple_text (GtkWidget *combo_box)
-{
-	GtkCellRenderer *cell;
-	GtkListStore *store;
-
-	store = gtk_list_store_new (1, G_TYPE_STRING);
-	gtk_combo_box_set_model (GTK_COMBO_BOX (combo_box), GTK_TREE_MODEL (store));
-	g_object_unref (store);
-
-	cell = gtk_cell_renderer_text_new ();
-	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo_box), cell, TRUE);
-	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_box), cell,
-					"text", 0,
-					NULL);
-}
-
 /**
  * cc_power_panel_actions_destroy_cb:
  **/
@@ -170,7 +138,6 @@ cc_power_panel_setup_action_combo (CcPowerPanel *panel, const gchar *widget_name
 	GpmActionPolicy *actions_added;
 
 	widget = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder, widget_name));
-	cc_power_panel_set_combo_simple_text (widget);
 
 	value = g_settings_get_enum (panel->priv->settings, gpm_pref_key);
 	is_writable = g_settings_is_writable (panel->priv->settings, gpm_pref_key);
@@ -187,30 +154,27 @@ cc_power_panel_setup_action_combo (CcPowerPanel *panel, const gchar *widget_name
 		if (policy == GPM_ACTION_POLICY_SHUTDOWN && !panel->priv->can_shutdown) {
 			g_debug ("Cannot add option, as cannot shutdown.");
 		} else if (policy == GPM_ACTION_POLICY_SHUTDOWN && panel->priv->can_shutdown) {
-			gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Shutdown"));
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), _("Shutdown"));
 			g_ptr_array_add (array, GINT_TO_POINTER (policy));
 		} else if (policy == GPM_ACTION_POLICY_SUSPEND && !panel->priv->can_suspend) {
 			g_debug ("Cannot add option, as cannot suspend.");
 		} else if (policy == GPM_ACTION_POLICY_HIBERNATE && !panel->priv->can_hibernate) {
 			g_debug ("Cannot add option, as cannot hibernate.");
 		} else if (policy == GPM_ACTION_POLICY_SUSPEND && panel->priv->can_suspend) {
-			gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Suspend"));
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), _("Suspend"));
 			g_ptr_array_add (array, GINT_TO_POINTER (policy));
 		} else if (policy == GPM_ACTION_POLICY_HIBERNATE && panel->priv->can_hibernate) {
-			gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Hibernate"));
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), _("Hibernate"));
 			g_ptr_array_add (array, GINT_TO_POINTER (policy));
 		} else if (policy == GPM_ACTION_POLICY_BLANK) {
-			gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Blank screen"));
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), _("Blank screen"));
 			g_ptr_array_add (array, GINT_TO_POINTER (policy));
 		} else if (policy == GPM_ACTION_POLICY_INTERACTIVE) {
-			gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Ask me"));
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), _("Ask me"));
 			g_ptr_array_add (array, GINT_TO_POINTER (policy));
 		} else if (policy == GPM_ACTION_POLICY_NOTHING) {
-			/* we only add do nothing in the GUI if the user has explicitly specified this in GConf */
-			if (value == GPM_ACTION_POLICY_NOTHING) {
-				gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Do nothing"));
-				g_ptr_array_add (array, GINT_TO_POINTER (policy));
-			}
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), _("Do nothing"));
+			g_ptr_array_add (array, GINT_TO_POINTER (policy));
 		} else {
 			g_warning ("Unknown action read from settings: %i", policy);
 		}
@@ -234,43 +198,78 @@ cc_power_panel_setup_action_combo (CcPowerPanel *panel, const gchar *widget_name
 	g_ptr_array_unref (array);
 }
 
+/**
+ * cc_power_panel_delete_array:
+ **/
+static void
+cc_power_panel_delete_array (GArray *array)
+{
+	g_array_free (array, TRUE);
+}
+
 /**
  * cc_power_panel_setup_time_combo:
  **/
 static void
 cc_power_panel_setup_time_combo (CcPowerPanel *panel, const gchar *widget_name,
-			    const gchar *gpm_pref_key, const gint *values)
+			    const gchar *gpm_pref_key, const gint *values_in)
 {
 	guint value;
 	gchar *text;
 	guint i;
+	gint values_in_len;
+	gint loop_value;
 	gboolean is_writable;
+	gboolean found_value = FALSE;
+	gint found_index = -1;
 	GtkWidget *widget;
+	GArray *values;
 
 	widget = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder, widget_name));
-	cc_power_panel_set_combo_simple_text (widget);
 
 	value = g_settings_get_int (panel->priv->settings, gpm_pref_key);
 	is_writable = g_settings_is_writable (panel->priv->settings, gpm_pref_key);
 	gtk_widget_set_sensitive (widget, is_writable);
 
+	/* Search values to see if current value is already listed.  If not,
+	   we will add it ourselves. */
+	for (i=0; values_in[i] != -1; i++) {
+		if (value == values_in[i])
+			found_value = TRUE;
+		if (found_index == -1 && (values_in[i] == 0 || value < values_in[i]))
+			found_index = i;
+	}
+	values_in_len = i + 1;
+	if (value == 0) /* 'Never' should always be last */
+		found_index = values_in_len - 1;
+
+	/* Build array of values */
+	values = g_array_sized_new (FALSE, FALSE, sizeof (gint),
+	                            values_in_len + (found_value ? 0 : 1));
+	g_array_append_vals (values, values_in, values_in_len);
+	if (!found_value)
+		g_array_insert_val (values, found_index, value);
+
 	g_object_set_data (G_OBJECT (widget), "settings_key", (gpointer) gpm_pref_key);
-	g_object_set_data (G_OBJECT (widget), "values", (gpointer) values);
+	g_object_set_data_full (G_OBJECT (widget), "values", (gpointer) values,
+	                        (GDestroyNotify) cc_power_panel_delete_array);
 
 	/* add each time */
-	for (i=0; values[i] != -1; i++) {
+	for (i=0; g_array_index (values, gint, i) != -1; i++) {
 
+		loop_value = g_array_index (values, gint, i);
+ 
 		/* get translation for number of seconds */
-		if (values[i] != 0) {
-			text = gpm_get_timestring (values[i]);
-			gtk_combo_box_append_text (GTK_COMBO_BOX (widget), text);
+		if (loop_value != 0) {
+			text = gpm_get_timestring (loop_value);
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), text);
 			g_free (text);
 		} else {
-			gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Never"));
+			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), _("Never"));
 		}
 
 		/* matches, so set default */
-		if (value == values[i])
+		if (value == loop_value)
 			 gtk_combo_box_set_active (GTK_COMBO_BOX (widget), i);
 	}
 
@@ -279,63 +278,6 @@ cc_power_panel_setup_time_combo (CcPowerPanel *panel, const gchar *widget_name,
 			  G_CALLBACK (cc_power_panel_action_time_changed_cb), panel);
 }
 
-/** setup the notification page */
-static void
-cc_power_panel_setup_notification (CcPowerPanel *panel)
-{
-	gint icon_policy;
-	GtkWidget *radiobutton_icon_present;
-	GtkWidget *radiobutton_icon_charge;
-	GtkWidget *radiobutton_icon_low;
-	GtkWidget *radiobutton_icon_never;
-	gboolean is_writable;
-
-	icon_policy = g_settings_get_enum (panel->priv->settings, GPM_SETTINGS_ICON_POLICY);
-	radiobutton_icon_present = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder,
-					       "radiobutton_notification_present"));
-	radiobutton_icon_charge = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder,
-					      "radiobutton_notification_charge"));
-	radiobutton_icon_low = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder,
-					   "radiobutton_notification_low"));
-	radiobutton_icon_never = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder,
-					     "radiobutton_notification_never"));
-
-	is_writable = g_settings_is_writable (panel->priv->settings, GPM_SETTINGS_ICON_POLICY);
-	gtk_widget_set_sensitive (radiobutton_icon_present, is_writable);
-	gtk_widget_set_sensitive (radiobutton_icon_charge, is_writable);
-	gtk_widget_set_sensitive (radiobutton_icon_low, is_writable);
-	gtk_widget_set_sensitive (radiobutton_icon_never, is_writable);
-
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_present),
-				      icon_policy == GPM_ICON_POLICY_PRESENT);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_charge),
-				      icon_policy == GPM_ICON_POLICY_CHARGE);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_low),
-				      icon_policy == GPM_ICON_POLICY_LOW);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_never),
-				      icon_policy == GPM_ICON_POLICY_NEVER);
-
-	g_object_set_data (G_OBJECT (radiobutton_icon_present), "policy",
-			   GINT_TO_POINTER (GPM_ICON_POLICY_PRESENT));
-	g_object_set_data (G_OBJECT (radiobutton_icon_charge), "policy",
-			   GINT_TO_POINTER (GPM_ICON_POLICY_CHARGE));
-	g_object_set_data (G_OBJECT (radiobutton_icon_low), "policy",
-			   GINT_TO_POINTER (GPM_ICON_POLICY_LOW));
-	g_object_set_data (G_OBJECT (radiobutton_icon_never), "policy",
-			   GINT_TO_POINTER (GPM_ICON_POLICY_NEVER));
-
-	/* only connect the callbacks after we set the value, else the settings
-	 * keys gets written to (for a split second), and the icon flickers. */
-	g_signal_connect (radiobutton_icon_present, "clicked",
-			  G_CALLBACK (cc_power_panel_icon_radio_cb), panel);
-	g_signal_connect (radiobutton_icon_charge, "clicked",
-			  G_CALLBACK (cc_power_panel_icon_radio_cb), panel);
-	g_signal_connect (radiobutton_icon_low, "clicked",
-			  G_CALLBACK (cc_power_panel_icon_radio_cb), panel);
-	g_signal_connect (radiobutton_icon_never, "clicked",
-			  G_CALLBACK (cc_power_panel_icon_radio_cb), panel);
-}
-
 /**
  * cc_power_panel_setup_ac:
  **/
@@ -379,11 +321,11 @@ cc_power_panel_setup_ac (CcPowerPanel *panel)
 				      button_lid_actions);
 
 	/* setup brightness slider */
-	widget = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder, "hscale_ac_brightness"));
-	g_settings_bind (panel->priv->settings, GPM_SETTINGS_BRIGHTNESS_AC,
-			 widget, "fill-level",
-			 G_SETTINGS_BIND_DEFAULT);
-	g_signal_connect (G_OBJECT (widget), "format-value",
+//	widget = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder, "hscale_ac_brightness"));
+//	g_settings_bind (panel->priv->settings, GPM_SETTINGS_BRIGHTNESS_AC,
+//			 widget, "fill-level",
+//			 G_SETTINGS_BIND_DEFAULT);
+if(0)	g_signal_connect (G_OBJECT (widget), "format-value",
 			  G_CALLBACK (cc_power_panel_format_percentage_cb), NULL);
 
 	/* set up the checkboxes */
@@ -398,13 +340,13 @@ cc_power_panel_setup_ac (CcPowerPanel *panel)
 
 	if (panel->priv->has_button_lid == FALSE) {
 		widget = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder, "hbox_ac_lid"));
-		gtk_widget_hide_all (widget);
+		gtk_widget_hide (widget);
 	}
 	if (panel->priv->has_lcd == FALSE) {
 		widget = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder, "hbox_ac_brightness"));
-		gtk_widget_hide_all (widget);
+		gtk_widget_hide (widget);
 		widget = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder, "checkbutton_ac_display_dim"));
-		gtk_widget_hide_all (widget);
+		gtk_widget_hide (widget);
 	}
 }
 
@@ -486,11 +428,11 @@ cc_power_panel_setup_battery (CcPowerPanel *panel)
 
 	if (panel->priv->has_button_lid == FALSE) {
 		widget = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder, "hbox_battery_lid"));
-		gtk_widget_hide_all (widget);
+		gtk_widget_hide (widget);
 	}
 	if (panel->priv->has_lcd == FALSE) {
 		widget = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder, "checkbutton_battery_display_dim"));
-		gtk_widget_hide_all (widget);
+		gtk_widget_hide (widget);
 	}
 }
 
@@ -577,7 +519,7 @@ cc_power_panel_setup_general (CcPowerPanel *panel)
 
 	if (panel->priv->has_button_suspend == FALSE) {
 		widget = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder, "hbox_general_suspend"));
-		gtk_widget_hide_all (widget);
+		gtk_widget_hide (widget);
 	}
 }
 
@@ -588,8 +530,8 @@ cc_power_panel_setup_general (CcPowerPanel *panel)
 static void
 cc_power_panel_set_defaults_cb (GtkWidget *widget, CcPowerPanel *panel)
 {
-	DBusGProxy *proxy;
-	DBusGConnection *connection;
+	GDBusProxy *proxy;
+	GDBusConnection *connection;
 	GError *error = NULL;
 	const gchar *keys[5] = {
 		"/apps/gnome-power-manager/actions",
@@ -599,7 +541,7 @@ cc_power_panel_set_defaults_cb (GtkWidget *widget, CcPowerPanel *panel)
 		"/apps/gnome-power-manager/timeout"
 	};
 
-	connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
+	connection = g_bus_get_sync (G_BUS_TYPE_SYSTEM, NULL, &error);
 	if (error != NULL) {
 		g_warning ("failed to get system bus connection: %s", error->message);
 		g_error_free (error);
@@ -615,7 +557,7 @@ cc_power_panel_set_defaults_cb (GtkWidget *widget, CcPowerPanel *panel)
 		return;
 	}
 
-	dbus_g_proxy_call (proxy, "SetSystem", &error,
+	g_dbus_proxy_call (proxy, "SetSystem", &error,
 			   G_TYPE_STRV, keys,
 			   G_TYPE_STRV, NULL,
 			   G_TYPE_INVALID, G_TYPE_INVALID);
@@ -735,7 +677,6 @@ cc_power_panel_init (CcPowerPanel *panel)
 	cc_power_panel_setup_battery (panel);
 	cc_power_panel_setup_ups (panel);
 	cc_power_panel_setup_general (panel);
-	cc_power_panel_setup_notification (panel);
 
 out:
 	main_window = GTK_WIDGET (gtk_builder_get_object (panel->priv->builder, "dialog_preferences"));
