@@ -38,7 +38,6 @@
 #endif /* HAVE_UNISTD_H */
 
 #include <glib/gi18n.h>
-#include <dbus/dbus-glib.h>
 #include <libupower-glib/upower.h>
 
 #include "gpm-button.h"
@@ -46,7 +45,6 @@
 #include "gpm-brightness.h"
 #include "gpm-control.h"
 #include "gpm-common.h"
-#include "egg-debug.h"
 #include "gsd-media-keys-window.h"
 #include "gpm-dpms.h"
 #include "gpm-idle.h"
@@ -54,6 +52,22 @@
 #include "gpm-stock-icons.h"
 #include "egg-console-kit.h"
 
+static const gchar *backlight_introspection = ""
+"<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
+"<node name=\"/\">"
+  "<interface name=\"org.gnome.PowerManager.Backlight\">"
+    "<method name=\"GetBrightness\">"
+      "<arg type=\"u\" name=\"percentage_brightness\" direction=\"out\"/>"
+    "</method>"
+    "<method name=\"SetBrightness\">"
+      "<arg type=\"u\" name=\"percentage_brightness\" direction=\"in\"/>"
+    "</method>"
+    "<signal name=\"BrightnessChanged\">"
+      "<arg type=\"u\" name=\"percentage_brightness\" direction=\"out\"/>"
+    "</signal>"
+  "</interface>"
+"</node>";
+
 #define GPM_BACKLIGHT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_BACKLIGHT, GpmBacklightPrivate))
 
 struct GpmBacklightPrivate
@@ -72,6 +86,8 @@ struct GpmBacklightPrivate
 	GTimer			*idle_timer;
 	guint			 idle_dim_timeout;
 	guint			 master_percentage;
+	GDBusConnection		*bus_connection;
+	guint			 bus_object_id;
 };
 
 enum {
@@ -160,7 +176,7 @@ gpm_backlight_set_brightness (GpmBacklight *backlight, guint percentage, GError
 	}
 	/* we emit a signal for the brightness applet */
 	if (ret && hw_changed) {
-		egg_debug ("emitting brightness-changed : %i", percentage);
+		g_debug ("emitting brightness-changed : %i", percentage);
 		g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, percentage);
 	}
 	return ret;
@@ -175,7 +191,7 @@ static void
 gpm_backlight_dialog_init (GpmBacklight *backlight)
 {
 	if (backlight->priv->popup != NULL
-	    && !gsd_media_keys_window_is_valid (GSD_MEDIA_KEYS_WINDOW (backlight->priv->popup))) {
+	    && !gsd_osd_window_is_valid (GSD_OSD_WINDOW (backlight->priv->popup))) {
 		gtk_widget_destroy (backlight->priv->popup);
 		backlight->priv->popup = NULL;
 	}
@@ -216,7 +232,7 @@ gpm_backlight_dialog_show (GpmBacklight *backlight)
 	 * know its true size, yet, so we need to jump through hoops
 	 */
 	gtk_window_get_default_size (GTK_WINDOW (backlight->priv->popup), &orig_w, &orig_h);
-	gtk_widget_size_request (backlight->priv->popup, &win_req);
+	gtk_widget_get_preferred_size(backlight->priv->popup, &win_req, NULL);
 
 	if (win_req.width > orig_w) {
 		orig_w = win_req.width;
@@ -283,19 +299,19 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 	guint old_value;
 
 	if (backlight->priv->can_dim == FALSE) {
-		egg_warning ("no dimming hardware");
+		g_warning ("no dimming hardware");
 		return FALSE;
 	}
 
 	do_laptop_lcd = g_settings_get_boolean (backlight->priv->settings, GPM_SETTINGS_BACKLIGHT_ENABLE);
 	if (do_laptop_lcd == FALSE) {
-		egg_warning ("policy is no dimming");
+		g_warning ("policy is no dimming");
 		return FALSE;
 	}
 
 	/* get the last set brightness */
 	brightness = backlight->priv->master_percentage / 100.0f;
-	egg_debug ("1. main brightness %f", brightness);
+	g_debug ("1. main brightness %f", brightness);
 
 	/* get battery status */
 	g_object_get (backlight->priv->client,
@@ -307,7 +323,7 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 	if (on_battery && battery_reduce) {
 		value = g_settings_get_int (backlight->priv->settings, GPM_SETTINGS_BRIGHTNESS_DIM_BATT);
 		if (value > 100) {
-			egg_warning ("cannot use battery brightness value %i, correcting to 50", value);
+			g_warning ("cannot use battery brightness value %i, correcting to 50", value);
 			value = 50;
 		}
 		scale = (100 - value) / 100.0f;
@@ -315,7 +331,7 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 	} else {
 		scale = 1.0f;
 	}
-	egg_debug ("2. battery scale %f, brightness %f", scale, brightness);
+	g_debug ("2. battery scale %f, brightness %f", scale, brightness);
 
 	/* reduce if system is momentarily idle */
 	if (!on_battery)
@@ -325,7 +341,7 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 	if (enable_action && backlight->priv->system_is_idle) {
 		value = g_settings_get_int (backlight->priv->settings, GPM_SETTINGS_IDLE_BRIGHTNESS);
 		if (value > 100) {
-			egg_warning ("cannot use idle brightness value %i, correcting to 50", value);
+			g_warning ("cannot use idle brightness value %i, correcting to 50", value);
 			value = 50;
 		}
 		scale = value / 100.0f;
@@ -333,7 +349,7 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 	} else {
 		scale = 1.0f;
 	}
-	egg_debug ("3. idle scale %f, brightness %f", scale, brightness);
+	g_debug ("3. idle scale %f, brightness %f", scale, brightness);
 
 	/* convert to percentage */
 	value = (guint) ((brightness * 100.0f) + 0.5);
@@ -341,7 +357,7 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 	/* only do stuff if the brightness is different */
 	gpm_brightness_get (backlight->priv->brightness, &old_value);
 	if (old_value == value) {
-		egg_debug ("values are the same, no action");
+		g_debug ("values are the same, no action");
 		return FALSE;
 	}
 
@@ -356,7 +372,7 @@ gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean int
 	ret = gpm_brightness_set (backlight->priv->brightness, value, &hw_changed);
 	/* we emit a signal for the brightness applet */
 	if (ret && hw_changed) {
-		egg_debug ("emitting brightness-changed : %i", value);
+		g_debug ("emitting brightness-changed : %i", value);
 		g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, value);
 	}
 	return TRUE;
@@ -385,17 +401,17 @@ gpm_settings_key_changed_cb (GSettings *settings, const gchar *key, GpmBacklight
 		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 
 	} else if (g_strcmp0 (key, GPM_SETTINGS_IDLE_DIM_AC) == 0 ||
-	           g_strcmp0 (key, GPM_SETTINGS_BACKLIGHT_ENABLE) == 0 ||
-	           g_strcmp0 (key, GPM_SETTINGS_SLEEP_DISPLAY_BATT) == 0 ||
-	           g_strcmp0 (key, GPM_SETTINGS_BACKLIGHT_BATTERY_REDUCE) == 0 ||
-	           g_strcmp0 (key, GPM_SETTINGS_IDLE_BRIGHTNESS) == 0) {
+		   g_strcmp0 (key, GPM_SETTINGS_BACKLIGHT_ENABLE) == 0 ||
+		   g_strcmp0 (key, GPM_SETTINGS_SLEEP_DISPLAY_BATT) == 0 ||
+		   g_strcmp0 (key, GPM_SETTINGS_BACKLIGHT_BATTERY_REDUCE) == 0 ||
+		   g_strcmp0 (key, GPM_SETTINGS_IDLE_BRIGHTNESS) == 0) {
 		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 
 	} else if (g_strcmp0 (key, GPM_SETTINGS_IDLE_DIM_TIME) == 0) {
 		backlight->priv->idle_dim_timeout = g_settings_get_int (settings, key);
 		gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
 	} else {
-		egg_debug ("unknown key %s", key);
+		g_debug ("unknown key %s", key);
 	}
 }
 
@@ -426,7 +442,7 @@ gpm_backlight_button_pressed_cb (GpmButton *button, const gchar *type, GpmBackli
 	GError *error = NULL;
 	guint percentage;
 	gboolean hw_changed;
-	egg_debug ("Button press event type=%s", type);
+	g_debug ("Button press event type=%s", type);
 
 	if (g_strcmp0 (type, GPM_BUTTON_BRIGHT_UP) == 0) {
 		/* go up one step */
@@ -444,7 +460,7 @@ gpm_backlight_button_pressed_cb (GpmButton *button, const gchar *type, GpmBackli
 		}
 		/* we emit a signal for the brightness applet */
 		if (ret && hw_changed) {
-			egg_debug ("emitting brightness-changed : %i", percentage);
+			g_debug ("emitting brightness-changed : %i", percentage);
 			g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, percentage);
 		}
 	} else if (g_strcmp0 (type, GPM_BUTTON_BRIGHT_DOWN) == 0) {
@@ -463,7 +479,7 @@ gpm_backlight_button_pressed_cb (GpmButton *button, const gchar *type, GpmBackli
 		}
 		/* we emit a signal for the brightness applet */
 		if (ret && hw_changed) {
-			egg_debug ("emitting brightness-changed : %i", percentage);
+			g_debug ("emitting brightness-changed : %i", percentage);
 			g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, percentage);
 		}
 	} else if (g_strcmp0 (type, GPM_BUTTON_LID_OPEN) == 0) {
@@ -473,7 +489,7 @@ gpm_backlight_button_pressed_cb (GpmButton *button, const gchar *type, GpmBackli
 		/* ensure backlight is on */
 		ret = gpm_dpms_set_mode (backlight->priv->dpms, GPM_DPMS_MODE_ON, &error);
 		if (!ret) {
-			egg_warning ("failed to turn on DPMS: %s", error->message);
+			g_warning ("failed to turn on DPMS: %s", error->message);
 			g_error_free (error);
 		}
 	}
@@ -489,7 +505,7 @@ gpm_backlight_notify_system_idle_changed (GpmBacklight *backlight, gboolean is_i
 
 	/* no point continuing */
 	if (backlight->priv->system_is_idle == is_idle) {
-		egg_debug ("state not changed");
+		g_debug ("state not changed");
 		return FALSE;
 	}
 
@@ -498,14 +514,14 @@ gpm_backlight_notify_system_idle_changed (GpmBacklight *backlight, gboolean is_i
 	g_timer_reset (backlight->priv->idle_timer);
 
 	if (is_idle == FALSE) {
-		egg_debug ("we have just been idle for %lfs", elapsed);
+		g_debug ("we have just been idle for %lfs", elapsed);
 
 		/* The user immediatly undimmed the screen!
 		 * We should double the timeout to avoid this happening again */
 		if (elapsed < 10) {
 			/* double the event time */
 			backlight->priv->idle_dim_timeout *= 2.0;
-			egg_debug ("increasing idle dim time to %is", backlight->priv->idle_dim_timeout);
+			g_debug ("increasing idle dim time to %is", backlight->priv->idle_dim_timeout);
 			gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
 		}
 
@@ -516,20 +532,20 @@ gpm_backlight_notify_system_idle_changed (GpmBacklight *backlight, gboolean is_i
 			backlight->priv->idle_dim_timeout =
 				g_settings_get_int (backlight->priv->settings,
 					   GPM_SETTINGS_IDLE_DIM_TIME);
-			egg_debug ("resetting idle dim time to %is", backlight->priv->idle_dim_timeout);
+			g_debug ("resetting idle dim time to %is", backlight->priv->idle_dim_timeout);
 			gpm_idle_set_timeout_dim (backlight->priv->idle, backlight->priv->idle_dim_timeout);
 		}
 	} else {
-		egg_debug ("we were active for %lfs", elapsed);
+		g_debug ("we were active for %lfs", elapsed);
 	}
 
-	egg_debug ("changing powersave idle status to %i", is_idle);
+	g_debug ("changing powersave idle status to %i", is_idle);
 	backlight->priv->system_is_idle = is_idle;
 	return TRUE;
 }
 
 /**
- * idle_changed_cb:
+ * gpm_backlight_idle_changed_cb:
  * @idle: The idle class instance
  * @mode: The idle mode, e.g. GPM_IDLE_MODE_BLANK
  * @manager: This class instance
@@ -540,9 +556,10 @@ gpm_backlight_notify_system_idle_changed (GpmBacklight *backlight, gboolean is_i
  * session timeout has elapsed for the idle action.
  **/
 static void
-idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmBacklight *backlight)
+gpm_backlight_idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmBacklight *backlight)
 {
 	gboolean ret;
+	gboolean is_active;
 	GError *error = NULL;
 	gboolean on_battery;
 	GpmDpmsMode dpms_mode;
@@ -552,8 +569,13 @@ idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmBacklight *backlight)
 		return;
 
 	/* don't dim or undim the screen unless we are on the active console */
-	if (!egg_console_kit_is_active (backlight->priv->consolekit)) {
-		egg_debug ("ignoring as not on active console");
+	ret = egg_console_kit_is_active (backlight->priv->consolekit, &is_active, &error);
+	if (!ret) {
+		g_warning ("failed to get console active status: %s", error->message);
+		g_error_free (error);
+	}
+	if (!is_active) {
+		g_debug ("ignoring as not on active console");
 		return;
 	}
 
@@ -565,7 +587,7 @@ idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmBacklight *backlight)
 		/* ensure backlight is on */
 		ret = gpm_dpms_set_mode (backlight->priv->dpms, GPM_DPMS_MODE_ON, &error);
 		if (!ret) {
-			egg_warning ("failed to turn on DPMS: %s", error->message);
+			g_warning ("failed to turn on DPMS: %s", error->message);
 			g_error_free (error);
 		}
 
@@ -578,7 +600,7 @@ idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmBacklight *backlight)
 		/* ensure backlight is on */
 		ret = gpm_dpms_set_mode (backlight->priv->dpms, GPM_DPMS_MODE_ON, &error);
 		if (!ret) {
-			egg_warning ("failed to turn on DPMS: %s", error->message);
+			g_warning ("failed to turn on DPMS: %s", error->message);
 			g_error_free (error);
 		}
 
@@ -599,21 +621,21 @@ idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmBacklight *backlight)
 
 		/* check if method is valid */
 		if (dpms_mode == GPM_DPMS_MODE_UNKNOWN || dpms_mode == GPM_DPMS_MODE_ON) {
-			egg_warning ("BACKLIGHT method %s unknown. Using OFF.", gpm_dpms_mode_to_string (dpms_mode));
+			g_warning ("BACKLIGHT method %s unknown. Using OFF.", gpm_dpms_mode_to_string (dpms_mode));
 			dpms_mode = GPM_DPMS_MODE_OFF;
 		}
 
 		/* turn backlight off */
 		ret = gpm_dpms_set_mode (backlight->priv->dpms, dpms_mode, &error);
 		if (!ret) {
-			egg_warning ("failed to change DPMS: %s", error->message);
+			g_warning ("failed to change DPMS: %s", error->message);
 			g_error_free (error);
 		}
 	}
 }
 
 /**
- * brightness_changed_cb:
+ * gpm_backlight_brightness_changed_cb:
  * @brightness: The GpmBrightness class instance
  * @percentage: The new percentage brightness
  * @brightness: This class instance
@@ -621,25 +643,34 @@ idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, GpmBacklight *backlight)
  * This callback is called when the brightness value changes.
  **/
 static void
-brightness_changed_cb (GpmBrightness *brightness, guint percentage, GpmBacklight *backlight)
+gpm_backlight_brightness_changed_cb (GpmBrightness *brightness, guint percentage, GpmBacklight *backlight)
 {
 	/* save the new percentage */
 	backlight->priv->master_percentage = percentage;
 
 	/* we emit a signal for the brightness applet */
-	egg_debug ("emitting brightness-changed : %i", percentage);
+	g_debug ("emitting brightness-changed : %i", percentage);
 	g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, percentage);
+
+	/* and one for Dbus users */
+	g_dbus_connection_emit_signal (backlight->priv->bus_connection,
+			NULL,
+			GPM_DBUS_PATH_BACKLIGHT,
+			GPM_DBUS_INTERFACE_BACKLIGHT,
+			"BrightnessChanged",
+			g_variant_new ("(u)", percentage),
+			NULL);
 }
 
 /**
- * control_resume_cb:
+ * gpm_backlight_control_resume_cb:
  * @control: The control class instance
  * @power: This power class instance
  *
  * We have to update the caches on resume
  **/
 static void
-control_resume_cb (GpmControl *control, GpmControlAction action, GpmBacklight *backlight)
+gpm_backlight_control_resume_cb (GpmControl *control, GpmControlAction action, GpmBacklight *backlight)
 {
 	gboolean ret;
 	GError *error = NULL;
@@ -647,11 +678,105 @@ control_resume_cb (GpmControl *control, GpmControlAction action, GpmBacklight *b
 	/* ensure backlight is on */
 	ret = gpm_dpms_set_mode (backlight->priv->dpms, GPM_DPMS_MODE_ON, &error);
 	if (!ret) {
-		egg_warning ("failed to turn on DPMS: %s", error->message);
+		g_warning ("failed to turn on DPMS: %s", error->message);
 		g_error_free (error);
 	}
 }
 
+/**
+ * gpm_backlight_dbus_method_call:
+ **/
+static void
+gpm_backlight_dbus_method_call (GDBusConnection *connection,
+				const gchar *sender, const gchar *object_path,
+				const gchar *interface_name, const gchar *method_name,
+				GVariant *parameters, GDBusMethodInvocation *invocation,
+				gpointer user_data)
+{
+	GError *error;
+	guint value;
+	gboolean ret;
+	GpmBacklight *backlight = GPM_BACKLIGHT (user_data);
+
+	if (g_strcmp0 (method_name, "GetBrightness") == 0) {
+		ret = gpm_backlight_get_brightness (backlight, &value, &error);
+		if (!ret) {
+			g_dbus_method_invocation_return_gerror (invocation, error);
+			g_error_free (error);
+		} else {
+			g_dbus_method_invocation_return_value (invocation, g_variant_new ("(u)", value));
+		}
+		return;
+	}
+	if (g_strcmp0 (method_name, "SetBrightness") == 0) {
+		g_variant_get (parameters, "(u)", &value);
+		ret = gpm_backlight_set_brightness (backlight, value, &error);
+		if (!ret) {
+			g_dbus_method_invocation_return_gerror (invocation, error);
+			g_error_free (error);
+		} else {
+			g_dbus_method_invocation_return_value (invocation, NULL);
+		}
+		return;
+	}
+	g_assert_not_reached ();
+}
+
+/**
+ * gpm_backlight_dbus_property_get:
+ **/
+static GVariant *
+gpm_backlight_dbus_property_get (GDBusConnection *connection,
+				 const gchar *sender, const gchar *object_path,
+				 const gchar *interface_name, const gchar *property_name,
+				 GError **error, gpointer user_data)
+{
+	/* do nothing, no properties defined */
+	return NULL;
+}
+
+/**
+ * gpm_backlight_dbus_property_set:
+ **/
+static gboolean
+gpm_backlight_dbus_property_set (GDBusConnection *connection,
+				 const gchar *sender, const gchar *object_path,
+				 const gchar *interface_name, const gchar *property_name,
+				 GVariant *value,
+				 GError**invocation, gpointer user_data)
+{
+	/* do nothing, no properties defined */
+	return FALSE;
+}
+
+/**
+ * gpm_backlight_register_dbus:
+ **/
+void
+gpm_backlight_register_dbus (GpmBacklight *backlight, GDBusConnection *connection)
+{
+	GDBusNodeInfo *node_info;
+	GDBusInterfaceInfo *interface_info;
+	GDBusInterfaceVTable interface_vtable = {
+			gpm_backlight_dbus_method_call,
+			gpm_backlight_dbus_property_get,
+			gpm_backlight_dbus_property_set
+	};
+
+	node_info = g_dbus_node_info_new_for_xml (backlight_introspection, NULL);
+	interface_info = g_dbus_node_info_lookup_interface (node_info, GPM_DBUS_INTERFACE_BACKLIGHT);
+
+	backlight->priv->bus_connection = g_object_ref (connection);
+	backlight->priv->bus_object_id =
+		g_dbus_connection_register_object (connection,
+						   GPM_DBUS_PATH_BACKLIGHT,
+						   interface_info,
+						   &interface_vtable,
+						   backlight,
+						   NULL, NULL);
+	g_dbus_node_info_unref (node_info);
+}
+
 /**
  * gpm_backlight_finalize:
  **/
@@ -663,6 +788,12 @@ gpm_backlight_finalize (GObject *object)
 	g_return_if_fail (GPM_IS_BACKLIGHT (object));
 	backlight = GPM_BACKLIGHT (object);
 
+	if (backlight->priv->bus_connection != NULL) {
+		g_dbus_connection_unregister_object (backlight->priv->bus_connection,
+						     backlight->priv->bus_object_id);
+		g_object_unref (backlight->priv->bus_connection);
+	}
+
 	g_timer_destroy (backlight->priv->idle_timer);
 	gtk_widget_destroy (backlight->priv->popup);
 
@@ -719,7 +850,7 @@ gpm_backlight_init (GpmBacklight *backlight)
 	/* watch for manual brightness changes (for the popup widget) */
 	backlight->priv->brightness = gpm_brightness_new ();
 	g_signal_connect (backlight->priv->brightness, "brightness-changed",
-			  G_CALLBACK (brightness_changed_cb), backlight);
+			  G_CALLBACK (gpm_backlight_brightness_changed_cb), backlight);
 
 	/* we use up_client for the ac-adapter-changed signal */
 	backlight->priv->client = up_client_new ();
@@ -745,7 +876,7 @@ gpm_backlight_init (GpmBacklight *backlight)
 	/* watch for idle mode changes */
 	backlight->priv->idle = gpm_idle_new ();
 	g_signal_connect (backlight->priv->idle, "idle-changed",
-			  G_CALLBACK (idle_changed_cb), backlight);
+			  G_CALLBACK (gpm_backlight_idle_changed_cb), backlight);
 
 	/* assumption */
 	backlight->priv->system_is_idle = FALSE;
@@ -757,7 +888,7 @@ gpm_backlight_init (GpmBacklight *backlight)
 	gsd_media_keys_window_set_action_custom (GSD_MEDIA_KEYS_WINDOW (backlight->priv->popup),
 						 "gpm-brightness-lcd",
 						 TRUE);
-        gtk_window_set_position (GTK_WINDOW (backlight->priv->popup), GTK_WIN_POS_NONE);
+	gtk_window_set_position (GTK_WINDOW (backlight->priv->popup), GTK_WIN_POS_NONE);
 
 	/* DPMS mode poll class */
 	backlight->priv->dpms = gpm_dpms_new ();
@@ -765,7 +896,7 @@ gpm_backlight_init (GpmBacklight *backlight)
 	/* we refresh DPMS on resume */
 	backlight->priv->control = gpm_control_new ();
 	g_signal_connect (backlight->priv->control, "resume",
-			  G_CALLBACK (control_resume_cb), backlight);
+			  G_CALLBACK (gpm_backlight_control_resume_cb), backlight);
 
 	/* Don't do dimming on inactive console */
 	backlight->priv->consolekit = egg_console_kit_new ();
