@@ -100,7 +100,8 @@ G_BEGIN_DECLS
 #define GPM_SETTINGS_NOTIFY_FULLY_CHARGED		"notify-fully-charged"
 #define GPM_SETTINGS_NOTIFY_SLEEP_FAILED		"notify-sleep-failed"
 #define GPM_SETTINGS_NOTIFY_SLEEP_FAILED_URI		"notify-sleep-failed-uri"
-#define GPM_SETTINGS_NOTIFY_LOW_POWER			"notify-low-power"
+#define GPM_SETTINGS_NOTIFY_LOW_POWER_SYSTEM		"notify-low-power-system"
+#define GPM_SETTINGS_NOTIFY_LOW_POWER_DEVICE		"notify-low-power-device"
 
 /* thresholds */
 #define GPM_SETTINGS_PERCENTAGE_LOW			"percentage-low"
@@ -138,25 +139,6 @@ G_BEGIN_DECLS
 #define GS_CONF_DIR					"/apps/gnome-screensaver"
 #define GS_CONF_PREF_LOCK_ENABLED			GS_CONF_DIR "/lock_enabled"
 
-/* libnotify dummy code */
-#ifndef HAVE_LIBNOTIFY
-#define	notify_init(f1)						/* nothing */
-#define	notify_is_initted(f1)					FALSE
-#define	notify_notification_close(f1,f2)			TRUE
-#define	notify_notification_show(f1,f2)				TRUE
-#define	notify_notification_set_timeout(f1,f2)			/* nothing */
-#define	notify_notification_set_urgency(f1,f2)			/* nothing */
-#define	notify_notification_add_action(f1,f2,f3,f4,f5,f6)	/* nothing */
-#define NotifyNotification					GtkWidget
-#define	NotifyUrgency						guint
-#define	notify_notification_new(f1,f2,f3,f4)			gtk_fixed_new()
-#define	notify_notification_new_with_status_icon(f1,f2,f3,f4)	gtk_fixed_new()
-#define NOTIFY_URGENCY_LOW					0
-#define NOTIFY_URGENCY_NORMAL					1
-#define NOTIFY_URGENCY_CRITICAL					2
-#define NOTIFY_EXPIRES_NEVER					0
-#endif
-
 typedef enum {
 	GPM_ICON_POLICY_PRESENT,
 	GPM_ICON_POLICY_CHARGE,
@@ -173,16 +155,42 @@ typedef enum {
 	GPM_ACTION_POLICY_INTERACTIVE,
 	GPM_ACTION_POLICY_NOTHING
 } GpmActionPolicy;
+#define	GPM_COLOR_WHITE			0xffffff
+#define	GPM_COLOR_BLACK			0x000000
+#define	GPM_COLOR_RED			0xff0000
+#define	GPM_COLOR_GREEN			0x00ff00
+#define	GPM_COLOR_BLUE			0x0000ff
+#define	GPM_COLOR_CYAN			0x00ffff
+#define	GPM_COLOR_MAGENTA		0xff00ff
+#define	GPM_COLOR_YELLOW		0xffff00
+#define	GPM_COLOR_GREY			0xcccccc
+#define	GPM_COLOR_DARK_RED		0x600000
+#define	GPM_COLOR_DARK_GREEN		0x006000
+#define	GPM_COLOR_DARK_BLUE		0x000060
+#define	GPM_COLOR_DARK_CYAN		0x006060
+#define	GPM_COLOR_DARK_MAGENTA		0x600060
+#define	GPM_COLOR_DARK_YELLOW		0x606000
+#define	GPM_COLOR_DARK_GREY		0x606060
 
 gchar		*gpm_get_timestring				(guint		 time);
-GpmIconPolicy	 gpm_icon_policy_from_string			(const gchar	*policy);
-const gchar	*gpm_icon_policy_to_string			(GpmIconPolicy	 policy);
-GpmActionPolicy	 gpm_action_policy_from_string			(const gchar	*policy);
-const gchar	*gpm_action_policy_to_string			(GpmActionPolicy  policy);
 void 		 gpm_help_display				(const gchar	*link_id);
-#ifdef EGG_TEST
-void		 gpm_common_test				(gpointer	 data);
-#endif
+gint		 gpm_precision_round_up				(gfloat		 value,
+								gint		 smallest);
+gint		 gpm_precision_round_down			(gfloat		 value,
+								gint		 smallest);
+guint		 gpm_discrete_from_percent			(guint		 percentage,
+								guint		 levels);
+guint		 gpm_discrete_to_percent			(guint		 discrete,
+								guint		 levels);
+gfloat		 gpm_discrete_to_fraction			(guint		 discrete,
+								guint		 levels);
+guint32		 gpm_color_from_rgb				(guint8		 red,
+								guint8		 green,
+								guint8		 blue);
+void		 gpm_color_to_rgb				(guint32	 color,
+								guint8		*red,
+								guint8		*green,
+								guint8		*blue);
 
 G_END_DECLS
 
